#
# spec file for package vis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define test_version 0.5
Name:           vis
Version:        0.8
Release:        bp156.3.3
Summary:        An editor combining the strengths of both vi(m) and sam
License:        ISC
Group:          Productivity/Text/Editors
URL:            https://github.com/martanne/vis
Source0:        https://github.com/martanne/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/martanne/vis-test/releases/download/v%{test_version}/vis-test-%{test_version}.tar.gz
# PATCH-FEATURE-UPSTREAM 675-nb-subproc-runner.patch gh#martanne/vis!675 mcepl@suse.com
# adds support for the non-blocking subprocess runner
Patch0:         675-nb-subproc-runner.patch
BuildRequires:  libselinux-devel
BuildRequires:  libtermkey-devel
BuildRequires:  lua-devel
BuildRequires:  lua-lpeg
BuildRequires:  ncurses-devel
BuildRequires:  tar
BuildRequires:  tre-devel
Requires:       lua
Suggests:       par_text
ExclusiveArch:  x86_64 %{ix86}
Suggests:       par_text

%description
Vis aims to be a modern, legacy free, simple yet efficient editor combining the strengths of both vi(m) and sam.

It extends vi's modal editing with built-in support for multiple cursors/selections and combines it with sam's structural regular expression based command language.

%prep
%autosetup -p1

tar -xC test/ --strip-components 1 -f %{SOURCE1}

%build
export CFLAGS="%{optflags} -fcommon"
%configure
%make_build debug

%install
%make_install

%check
# According to the debian/rules:
# The vim tests harness is not solid, let's skip them for the moment.
# Upstream mentioned the possibility of phasing them out entirely.
%make_build -C test/core
# No busted yet make -C test/lua
%make_build -C test/vis

%files
%{_bindir}/vis*
%{_datadir}/vis
%{_mandir}/man1/*
%dir %{_datadir}/doc/vis
%{_datadir}/doc/vis/LICENSE
%{_datadir}/doc/vis/README.md

%changelog
* Thu Jul 20 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Tue Feb 28 2023 Matej Cepl <mcepl@suse.com>
- Add 675-nb-subproc-runner.patch (gh#martanne/vis!675) with
  support for the non-blocking subprocess runner.
* Tue Nov  1 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.8:
  - build: add git based version information back
  - lexers: fix bug in bash lexer for last here-doc
  - vis: make O implementation independent of <Up> mapping
  - fix typos in comments
  - lua: fix luacheck warnings
  - vis: rename to/till motion internals
  - vis: implement multiline to/till motions
  - vis-lua: provide file.permission property
  - Mention pkg-config in README
  - lexers/strace: improve comments, field names and syscall results
  - lexers/git-rebase: also highlight break command
  - filetype: Set "bash" for APKBUILD and .ebuild.
  - filetype: Detect make shebang for "makefile".
  - Adding .sv extension to verilog syntax highlighter
  - build: update alpine in docker build to version 3.13
  - sam: only skip the last empty match if it follows a newline
  - sam: produce empty match at the end of looped range
  - test: update
  - gitignore: remove vim specific swap files
  - sam: tweak handling of zero length matches in y commands
  - sam: simplify trailing match handling for x/y commands
  - vis: correctly close pipe connected to stdin of external process
  - add lua5.4 in configure script
  - vis: Add readline Ctrl+A/E bindings
  - ci: verify codecov script before using it
  - ci: verify coverity scan script before using it
  - filetype: Set "groovy" for Jenkinsfile
  - README: x/freenode/c/libera/
  - Set version to 0.8
* Fri Feb  5 2021 Matej Cepl <mcepl@suse.com>
- Add BR libselinux-devel to make vis SELinux aware.
* Tue Dec  8 2020 Matej Cepl <mcepl@suse.com>
- Update to the released version 0.7:
  This is mostly a bug fix release with fixes for a few cases of
  undefined behavior and preliminary work for experimentation with
  different core text management data structures and general editor
  architecture.
  - fix UB in core text management data structure
  - text refactoring, splitting out reusable text iterator and I/O
    components
  - new *at() variants taking directory descriptor for file load/save
    API
  - more efficient initial file read, avoiding spurious syscalls and
    copy
  - text API cleanups, const correctness improvements
  - increased test coverage for core text data structure
  - support for Lua 5.4
  - Lua API improvements: vis.mark, vis.register, vis.win.file.modified
  - and support for terminal CSI events
  - NetBSD support
  - new :set ignorecase option to search case independently
  - new visual mode mapping <C-a> to select all matching selections
  - fix mappings involving non-leading <C-c>
  - minor file detection fixes for racket, node.js modules, Typescript
    and liliypond
  - new lexers for Zig, meson build system, Mikrotik RouterOS scripts,
    Gemini
  - improved inner word text object and its use for <C-n> in normal mode
  - improved <C-n> behavior in visual mode
  - removed ie, ae inner/outer entire text object, use :, as shorthand
    for :0,$
  - removed pairwise selection combinators z>, z<, z-, z+, z&, z|
  - remove ~ as alias for g~
  - use ~ instead of ! for selection complement
  - remove special key and window related aliases
  - vis-open(1) adds a trailing slash to indicate folders
  - add primary clipboard support to vis-clipboard(1)
  - support wayland clipboard using wl-clipboard(1)
  - new Makefile targets: distclean, testclean
* Mon Jun 15 2020 Matej Cepl <mcepl@suse.com>
- Update to the released version 0.6 (all changes since 0.5):
  - bounded time syntax highlighting using the :set redrawtime
    option
  - support optional count for sam's text commands e.g. :i3/-/
  - make <C-n> in visual mode match next occurence of existing
    selection
  - warn when attempting to write to an existing file
  - improved file change detection based on inode instead of path
    information
  - fix file saves with modifications in file pre-save events
  - fix save on file systems without fsync(2) support on
    directory descriptors
  - do not unlink file~ when saving file
  - introduce distinct vis-menu(1) exit codes
  - modify Lua package.path to include /init.lua
  - performance improvements for the HTML, XML and YAML lexers
  - new Julia and Elm lexers, better defaults for standard text
    lexer
  - support optional exit status in :q and :qall commands
  - better temporary file creation using mkstemp(2)
  - performance improvements in highlight matching parentheses
  - improved behavior of ^ and $ in searches and looping commands
  - improved search wrap around behavior
  - new :set layout option to specify window orientation
  - improved filetype detection by matching known filenames
    exactly
  - support DragonFly BSD in configure script
  - better manual page, fixed warnings
  - removed gp, gP, gq
  - implement g~, gu and gU using tr(1), they are no longer
    operators
  - removed v and V in operator pending mode
  - avoid crash if $TERM is unset
  - keep selections after :> command
  - normalize selections after : command execution
  - show pending input queue content in status bar
  - make r<Enter> insert a new line
  - new :set loadmethod option, valid values are read, mmap or
    auto
  - always apply :| command to existing selections
  - fix terminal UI on serial console
  - various code cleanups, removal of VLA
  - resets count, if applicable
  - fix :X and :Y commands which were interchanged
  - don't strip executables by default, provide install-strip
    target
* Fri Jun  5 2020 mcepl@cepl.eu
- Update to version 0.5+git.1590819266.c37f09e:
  * test: update
  * vis: fix implicit enum conversion warning
  * build: update alpine in docker build to version 3.12
  * doc: update outdated version information
  * doc: update sphinx configuration to python 3
  * test: update
  * text: introduce text_save_method, remove text_save_range
  * test: update
  * build: use -O2 by default
  * vis: cleanup pre-processing of :-commands
  * Tweak README
  * vt100: do not crash if termkey is not yet initialized
  * ui: fix line number drawing
  * build: fix _XOPEN_SOURCE redefinition warning
  * vis: make <Escape> reset count in visual modes
  * vis: make <Escape> reset count in normal mode
  * lexers: prioritize markdown list rule
  * lexers: make markdown white space rule less greedy
  * man: document theme location
  * Avoid use of VLAs
  * vt100: use shorter escape sequence to clear screen
  * Add Julia lexer
* Thu Apr 16 2020 mcepl@cepl.eu
- Update to version 0.5+git.1584517720.08a550d:
  * color-column: Don't change fg/bg if not set explicitly
  * Set single cursor style as primary, not secondary
  * sam: fix X and Y commands which were interchanged
  * Add Elm lexer
  * sam: fix spurious "file exists" warnings
* Wed Feb 26 2020 Matej Cepl <mcepl@suse.com>
- Fix the license: it is ISC, not MIT.
* Wed Feb 26 2020 mcepl@cepl.eu
- Update to version 0.5+git.1582699959.bdfea7e:
  * build: provide install-strip make target
  * ci: fix Alpine build by installing terminfo data
  * test: update
  * ci: remove Travis CI integration
  * ci: remove Appveyor integration
  * ci: improve OpenBSD Lua installation
  * ci: make sure en_US.UTF-8 locale is available on Debian
  * ci: disable codecov commit status updates
  * vis-lua: implement vis:redraw()
  * lua: add `redrawtime` option
* Wed Feb 26 2020 mcepl@cepl.eu
- Update to version 0.5+git.1582699959.bdfea7e:
  * build: provide install-strip make target
  * ci: fix Alpine build by installing terminfo data
  * test: update
  * ci: remove Travis CI integration
  * ci: remove Appveyor integration
  * ci: improve OpenBSD Lua installation
  * ci: make sure en_US.UTF-8 locale is available on Debian
  * ci: disable codecov commit status updates
  * vis-lua: implement vis:redraw()
  * lua: add `redrawtime` option
* Wed Feb 26 2020 Matej Cepl <mcepl@suse.com>
- The latest upstream commit doesn't strip binaries anymore
* Mon Feb 24 2020 Matej Cepl <mcepl@suse.com>
- make install STRIP=true to avoid stripping. Avoid public nudity!
  gh#martanne/vis#811
* Wed Dec 25 2019 Matej Cepl <mcepl@suse.com>
- Add BR of tre-devel, not just tre.
* Sat Sep 21 2019 Matej Cepl <mcepl@suse.com>
- Remove Debian-related files
- Add missing BRs.
* Mon Dec 12 2016 code@baez.nyc
  initial build from git
